==> nextcloud-31.0.4-1.0-any.pkg.tar.zst: usr/share/webapps/nextcloud/apps/serverinfo/l10n/ar.js <==
OC.L10N.register(
    "serverinfo",
    {
    "CPU info not available" : "المعلومات عن وحدة المعالجة المركزية CPU غير متوفرة",
    "CPU Usage:" : "استعمال وحدة المعالجة المركزية CPU: ",
    "Load average: {percentage} % ({load}) last minute" : "معدل التحميل: {percentage} % ({load}) آخر دقيقة",
    "{lastMinutePercentage} % ({lastMinute}) last Minute\n{last5MinutesPercentage} % ({last5Minutes}) last 5 Minutes\n{last15MinutesPercentage} % ({last15Minutes}) last 15 Minutes" : "{lastMinutePercentage} % ({lastMinute}) آخر دقيقة\n{last5MinutesPercentage} % ({last5Minutes}) آخر 5 دقائق\n{last15MinutesPercentage} % ({last15Minutes}) آخر 15 دقيقة",
    "RAM Usage:" : "استعمال الذاكرة العشوائية RAM: ",
    "SWAP Usage:" : "استعمال ذاكرة التبديل SWAP: ",
    "RAM: Total: {memTotalBytes}/Current usage: {memUsageBytes}" : "ذاكرة القراءة فقط RAM: المجموع : {memTotalBytes}/الاستعمال الحالي: {memUsageBytes}",
    "RAM info not available" : "المعلومات عن ذاكرة القراءة فقط RAM غير متوفرة",
    "SWAP: Total: {swapTotalBytes}/Current usage: {swapUsageBytes}" : "ذاكرة التبديل SWAP: المجموع: {swapTotalBytes}/الاستعمال الحالي: {swapUsageBytes}",
    "SWAP info not available" : "المعلومات عن ذاكرة التبديل SWAP غير متوفرة",
    "Copied!" : "تمّ النسخ!",
    "Not supported!" : "غير مدعوم!",
    "Press ⌘-C to copy." : "إضغط ⌘-C للنسخ",
    "Press Ctrl-C to copy." : "إضغط Ctrl-C للنسخ.",
    "System" : "النظام",
    "Monitoring" : "المراقبة",
    "Monitoring app with useful server information" : "تطبيق مراقبة مع معلومات مفيدة عن الخادم",
    "Provides useful server information, such as CPU load, RAM usage, disk usage, number of users, etc." : "يوفر معلومات مفيدة عن الخادم، مثل أحمال وحدة المعالجة المركزية CPU laod، و استخدامات ذاكرة الوصول العشوائي RAM usage، و استخدامات القرص disk usage، و عدد المستخدمين، و غيرها.",
    "Operating System:" : "نظام التشغيل:",
    "CPU:" : "وحدة الذاكرة المركزية CPU:",
    "Unknown Processor" : "معالِج غير معروف",
    "Memory:" : "الذاكرة:",
    "Server time:" : "وقت الخادم:",
    "Uptime:" : "مدة استمرارية التشغل uptime:",
    "Temperature" : "درجة الحرارة",
    "Load" : "الحمل",
    "Memory" : "الذاكرة",
    "Disk" : "القرص",
    "Mount:" : "إلحاق mount:",
    "Filesystem:" : "نظام الملفات:",
    "Size:" : "الحجم:",
    "Available:" : "مُتاحٌ:",
    "Used:" : "مُستعملٌ:",
    "Files:" : "الملفات:",
    "Storages:" : "وسائط التخزين:",
    "Free Space:" : "المساحة الحرة:",
    "Network" : "الشبكة",
    "Hostname:" : "اسم المُضِيف:",
    "Gateway:" : "البوابة gateway:",
    "Status:" : "الحالة status:",
    "Speed:" : "السرعة speed:",
    "Duplex:" : "الازدواج duplex:",
    "MAC:" : "رقم المُصنِّع للجهاز MAC:",
    "IPv4:" : "بروتوكول IPv4:",
    "IPv6:" : "بروتوكول IPv6:",
    "Active users" : "المستخدمون النشطون",
    "Last hour" : "آخر ساعة ",
    "%s%% of all users" : "%s%% من جميع المستخدمين",
    "Last 24 Hours" : "آخر 24 ساعة",
    "Last 7 Days" : "آخر 7 أيام",
    "Last 30 Days" : "آخر 30 يوم",
    "Shares" : "مشاركة",
    "Users:" : "المستخدمين:",
    "Groups:" : "المجموعات:",
    "Links:" : "الروابط:",
    "Emails:" : "حسابات البريد الالكتروني:",
    "Federated sent:" : "مرسل من السحابة الموحدة:",
    "Federated received:" : "مستقبل من السحابة الموحدة:",
    "Talk conversations:" : "مُحادثات Talk:",
    "PHP" : "PHP",
    "Version:" : "الأصدار:",
    "Memory limit:" : "حد الذاكرة:",
    "Max execution time:" : "أقصى زمن تنفيذ:",
    "Upload max size:" : "الحجم الأقصى للرفع:",
    "OPcache Revalidate Frequency:" : "تواتر إعادة مصادقة ذاكرة التخزين المؤقت OPcache:",
    "Extensions:" : "الامتدادات extensions:",
    "Unable to list extensions" : "تعذّر عرض قائمة بالامتدادات extensions:",
    "Show phpinfo" : "عرض ملف phpinfo",
    "FPM worker pool" : "حشد عمليات PHP-FPM",
    "Pool name:" : "اسم الحشد:",
    "Pool type:" : "نوع الحشد:",
    "Start time:" : "تاريخ البداية:",
    "Accepted connections:" : "التوصيلات المقبولة:",
    "Total processes:" : "إجمالي العمليات:",
    "Active processes:" : "عمليات نشطة:",
    "Idle processes:" : "عمليات خاملة:",
    "Listen queue:" : "طابور الاستماع:",
    "Slow requests:" : "طلبات بطيئة:",
    "Max listen queue:" : "أقصى طول لطابور الاستماع:",
    "Max active processes:" : "أقصى عدد من العمليات النشطة:",
    "Max children reached:" : "أقصى عدد من الأطفال يتم الوصول إليهم:",
    "Database" : "قاعدة البيانات",
    "Type:" : "النوع:",
    "External monitoring tool" : "أداة الرصد الخارجية",
    "Use this end point to connect an external monitoring tool:" : "إستعمِل هذه النقطة الحدِّيَّة end point لتوصيل أداة مراقبة خارجية:",
    "Copy" : "نسخ",
    "Output in JSON" : "المخرجات في صيغة JSON",
    "Skip apps section (including apps section will send an external request to the app store)" : "تخطِّي قسم التطبيقات (تضمين قسم التطبيقات سيرسل طلب خارجي إلى متجر التطبيقات)",
    "Skip server update" : "تخطِّي تحديثات الخادم",
    "To use an access token, please generate one then set it using the following command:" : "لاستخدام أَمَارَة وصول access token، يرجى توليد واحدةٍ ثم تعيينها باستخدام الأمر التالي:",
    "Then pass the token with the \"NC-Token\" header when querying the above URL." : "ثم قُم بتمرير الأَمَارَة talk برأس \"NC-Token\" عند الاستعلام عن عنوان الـ URL أعلاه.",
    "Load average: {cpu} (last minute)" : "مُعدَّل التحميل: {cpu} (last minute)",
    "DNS:" : "نظام تسمية النطاقات DNS:",
    "Total users:" : "العدد الإجمالي للمستخدمين:",
    "24 hours:" : "24 ساعة",
    "1 hour:" : "1 ساعة:",
    "5 mins:" : "5 دقائق:"
},
"nplurals=6; plural=n==0 ? 0 : n==1 ? 1 : n==2 ? 2 : n%100>=3 && n%100<=10 ? 3 : n%100>=11 && n%100<=99 ? 4 : 5;");

==> nextcloud-33.0.0-1-any.pkg.tar.zst: usr/share/webapps/nextcloud/apps/serverinfo/l10n/ar.js <==
OC.L10N.register(
    "serverinfo",
    {
    "CPU info not available" : "المعلومات عن وحدة المعالجة المركزية CPU غير متوفرة",
    "CPU Usage:" : "استعمال وحدة المعالجة المركزية CPU: ",
    "Load average: {percentage} % ({load}) last minute" : "معدل التحميل: {percentage} % ({load}) آخر دقيقة",
    "{lastMinutePercentage} % ({lastMinute}) last Minute\n{last5MinutesPercentage} % ({last5Minutes}) last 5 Minutes\n{last15MinutesPercentage} % ({last15Minutes}) last 15 Minutes" : "{lastMinutePercentage} % ({lastMinute}) آخر دقيقة\n{last5MinutesPercentage} % ({last5Minutes}) آخر 5 دقائق\n{last15MinutesPercentage} % ({last15Minutes}) آخر 15 دقيقة",
    "RAM Usage:" : "استعمال الذاكرة العشوائية RAM: ",
    "SWAP Usage:" : "استعمال ذاكرة التبديل SWAP: ",
    "RAM: Total: {memTotalBytes}/Current usage: {memUsageBytes}" : "ذاكرة القراءة فقط RAM: المجموع : {memTotalBytes}/الاستعمال الحالي: {memUsageBytes}",
    "RAM info not available" : "المعلومات عن ذاكرة القراءة فقط RAM غير متوفرة",
    "SWAP: Total: {swapTotalBytes}/Current usage: {swapUsageBytes}" : "ذاكرة التبديل SWAP: المجموع: {swapTotalBytes}/الاستعمال الحالي: {swapUsageBytes}",
    "SWAP info not available" : "المعلومات عن ذاكرة التبديل SWAP غير متوفرة",
    "Copied!" : "تمّ النسخ!",
    "Not supported!" : "غير مدعوم!",
    "Press ⌘-C to copy." : "إضغط ⌘-C للنسخ",
    "Press Ctrl-C to copy." : "إضغط Ctrl-C للنسخ.",
    "Unknown" : "غير معروف",
    "System" : "النظام",
    "Monitoring" : "المراقبة",
    "Monitoring app with useful server information" : "تطبيق مراقبة مع معلومات مفيدة عن الخادم",
    "Provides useful server information, such as CPU load, RAM usage, disk usage, number of users, etc." : "يوفر معلومات مفيدة عن الخادم، مثل أحمال وحدة المعالجة المركزية CPU laod، و استخدامات ذاكرة الوصول العشوائي RAM usage، و استخدامات القرص disk usage، و عدد المستخدمين، و غيرها.",
    "Operating System:" : "نظام التشغيل:",
    "CPU:" : "وحدة الذاكرة المركزية CPU:",
    "Memory:" : "الذاكرة:",
    "Server time:" : "وقت الخادم:",
    "Uptime:" : "مدة استمرارية التشغل uptime:",
    "Temperature" : "درجة الحرارة",
    "Load" : "الحمل",
    "Memory" : "الذاكرة",
    "Disk" : "القرص",
    "Mount:" : "إلحاق mount:",
    "Filesystem:" : "نظام الملفات:",
    "Size:" : "الحجم:",
    "Available:" : "مُتاحٌ:",
    "Used:" : "مُستعملٌ:",
    "Files:" : "الملفات:",
    "Storages:" : "وسائط التخزين:",
    "Free Space:" : "المساحة الحرة:",
    "Network" : "الشبكة",
    "Hostname:" : "اسم المُضِيف:",
    "Gateway:" : "البوابة gateway:",
    "Status:" : "الحالة status:",
    "Speed:" : "السرعة speed:",
    "Duplex:" : "الازدواج duplex:",
    "MAC:" : "رقم المُصنِّع للجهاز MAC:",
    "IPv4:" : "بروتوكول IPv4:",
    "IPv6:" : "بروتوكول IPv6:",
    "Active users" : "المستخدمون النشطون",
    "Last hour" : "آخر ساعة ",
    "%s%% of all users" : "%s%% من جميع المستخدمين",
    "Last 24 Hours" : "آخر 24 ساعة",
    "Last 7 Days" : "آخر 7 أيام",
    "Last 30 Days" : "آخر 30 يوم",
    "Shares" : "مشاركة",
    "Users:" : "المستخدمين:",
    "Groups:" : "المجموعات:",
    "Links:" : "الروابط:",
    "Emails:" : "حسابات البريد الالكتروني:",
    "Federated sent:" : "مرسل من السحابة الموحدة:",
    "Federated received:" : "مستقبل من السحابة الموحدة:",
    "Talk conversations:" : "مُحادثات Talk:",
    "PHP" : "PHP",
    "Version:" : "الأصدار:",
    "Memory limit:" : "حد الذاكرة:",
    "Max execution time:" : "أقصى زمن تنفيذ:",
    "seconds" : "ثوانٍ",
    "Upload max size:" : "الحجم الأقصى للرفع:",
    "OPcache Revalidate Frequency:" : "تواتر إعادة مصادقة ذاكرة التخزين المؤقت OPcache:",
    "Extensions:" : "الامتدادات extensions:",
    "Unable to list extensions" : "تعذّر عرض قائمة بالامتدادات extensions:",
    "Show phpinfo" : "عرض ملف phpinfo",
    "FPM worker pool" : "حشد عمليات PHP-FPM",
    "Pool name:" : "اسم الحشد:",
    "Pool type:" : "نوع الحشد:",
    "Start time:" : "تاريخ البداية:",
    "Accepted connections:" : "التوصيلات المقبولة:",
    "Total processes:" : "إجمالي العمليات:",
    "Active processes:" : "عمليات نشطة:",
    "Idle processes:" : "عمليات خاملة:",
    "Listen queue:" : "طابور الاستماع:",
    "Slow requests:" : "طلبات بطيئة:",
    "Max listen queue:" : "أقصى طول لطابور الاستماع:",
    "Max active processes:" : "أقصى عدد من العمليات النشطة:",
    "Max children reached:" : "أقصى عدد من الأطفال يتم الوصول إليهم:",
    "Database" : "قاعدة البيانات",
    "Type:" : "النوع:",
    "External monitoring tool" : "أداة الرصد الخارجية",
    "Use this end point to connect an external monitoring tool:" : "إستعمِل هذه النقطة الحدِّيَّة end point لتوصيل أداة مراقبة خارجية:",
    "Copy" : "نسخ",
    "Output in JSON" : "المخرجات في صيغة JSON",
    "Skip apps section (including apps section will send an external request to the app store)" : "تخطِّي قسم التطبيقات (تضمين قسم التطبيقات سيرسل طلب خارجي إلى متجر التطبيقات)",
    "Skip server update" : "تخطِّي تحديثات الخادم",
    "To use an access token, please generate one then set it using the following command:" : "لاستخدام أَمَارَة وصول access token، يرجى توليد واحدةٍ ثم تعيينها باستخدام الأمر التالي:",
    "Then pass the token with the \"NC-Token\" header when querying the above URL." : "ثم قُم بتمرير الأَمَارَة talk برأس \"NC-Token\" عند الاستعلام عن عنوان الـ URL أعلاه.",
    "Unknown Processor" : "معالِج غير معروف"
},
"nplurals=6; plural=n==0 ? 0 : n==1 ? 1 : n==2 ? 2 : n%100>=3 && n%100<=10 ? 3 : n%100>=11 && n%100<=99 ? 4 : 5;");
